macholib.MachO — Utilities for reading and writing Mach-O headers — macholib v1.4.3 documentation

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »

# `macholib.MachO` — Utilities for reading and writing Mach-O headers

This module defines a class `Macho`, which enables reading and writing the Mach-O header of an executable file or dynamic library on MacOS X.

class `macholib.MachO.` `MachO`(filename)

  Creates a MachO object by reading the Mach-O headers from filename.

  The filename should refer to an existing file in Mach-O format, and can refer to fat (universal) binaries.

Note

more information will be added later

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »